import { ChatSDK } from '@tencentcloud/chat';

type func = (...args: any[]) => any;
interface CallServiceParams {
    serviceName: string;
    method: string;
    params: Record<string, any>;
    callback?: func;
}
interface ExtensionInfo {
    weight: number;
    text: string;
    icon: string;
    data: Record<string, any>;
    listener: {
        onClicked?: func;
        onLongPressed?: func;
        onTouched?: func;
        onSwiped?: func;
    };
}
interface LoginParams {
    SDKAppID: number;
    userID: string;
    userSig: string;
    TIMPush?: any;
    pushConfig?: any;
    TUIOfflinePush?: any;
    offlinePushConfig?: any;
    useUploadPlugin?: boolean;
    useProfanityFilterPlugin?: boolean;
    unlimitedAVChatRoom?: boolean;
    scene?: string;
    fileUploadProxy?: string;
    fileDownloadProxy?: string;
    proxyServer?: string;
    devMode?: boolean;
    framework?: 'vue2' | 'vue3' | string | undefined;
}

interface ITUIService {
    onCall(method: string, params: object, callback?: func): void;
}

interface ITUICore {
    registerService(serviceName: string, service: any): void;
    unregisterService(serviceName: string): void;
    getService(serviceName: string): ITUIService;
    callService(options: CallServiceParams): void;
    registerExtension(extensionID: string, extension: any): void;
    unregisterExtension(extensionID: string, extension: any): void;
    getExtensionList(extensionID: string, params?: object): Array<ExtensionInfo>;
    registerEvent(eventName: string, subKey: string, notification: any): void;
    unregisterEvent(eventName: string, subKey: string, notification: any): void;
    notifyEvent(eventName: string, subKey: string, params?: object): void;
}

interface GetContextResult {
    chat: ChatSDK;
    SDKAppID: number;
    userID: string;
    userSig: string;
}
interface ITUILogin {
    login(options: LoginParams): Promise<any>;
    logout(): Promise<any>;
    destroy(): Promise<any>;
    setLogLevel(level: number): void;
    getContext(): GetContextResult;
}

declare const TUIConstants: {
    TUILogin: {
        EVENT: {
            LOGIN_STATE_CHANGED: string;
        };
        EVENT_SUB_KEY: {
            USER_LOGIN_SUCCESS: string;
            USER_LOGOUT_SUCCESS: string;
            USER_KICKED_OFFLINE: string;
            USER_SIG_EXPIRED: string;
        };
    };
    TUIConversation: {
        SERVICE: {
            NAME: string;
            METHOD: {
                CREATE_CONVERSATION: string;
                HIDE_CONVERSATION_HEADER: string;
            };
        };
        EXTENSION: {
            CONV_POP_MENU: {
                EXT_ID: string;
            };
            CONV_GROUP: {
                EXT_ID: string;
            };
        };
    };
    TUIChat: {
        SERVICE: {
            NAME: string;
            METHOD: {
                UPDATE_MESSAGE_LIST: string;
                CLOSE_MESSAGE_POP_MENU: string;
                SEND_CUSTOM_MESSAGE: string;
                SEND_TEXT_MESSAGE: string;
                SET_CHAT_TYPE: string;
            };
        };
        EXTENSION: {
            INPUT_MORE: {
                EXT_ID: string;
            };
            MSG_POP_MENU: {
                EXT_ID: string;
            };
            CHAT_HEADER: {
                EXT_ID: string;
            };
        };
        TYPE: {
            C2C: string;
            GROUP: string;
            CUSTOMER_SERVICE: string;
            ROOM: string;
        };
    };
    TUIGroup: {
        SERVICE: {
            NAME: string;
            METHOD: {
                CREATE_GROUP: string;
                OPEN_GROUP_MANAGEMENT: string;
                SELECT_GROUP_MEMBER: string;
            };
        };
    };
    TUIContact: {
        SERVICE: {
            NAME: string;
            METHOD: {
                SELECT_FRIEND: string;
            };
        };
        EXTENSION: {
            CONTACT_LIST: {
                EXT_ID: string;
            };
        };
    };
    TUISearch: {
        SERVICE: {
            NAME: string;
            METHOD: {
                SEARCH_GROUP: string;
                SEARCH_USER: string;
                SEARCH_FRIEND: string;
                SEARCH_GROUP_MEMBER: string;
            };
        };
        EXTENSION: {
            SEARCH_MORE: {
                EXT_ID: string;
            };
        };
    };
    TUICalling: {
        SERVICE: {
            NAME: string;
            METHOD: {
                START_CALL: string;
            };
        };
    };
    TUIEmojiPlugin: {
        SERVICE: {
            NAME: string;
            METHOD: {
                CLOSE_EMOJI_DETAIL: string;
            };
        };
    };
    TUITranslate: {
        EVENT: {
            LANGUAGE_CHANGED: string;
        };
        EVENT_SUB_KEY: {
            CHANGE_SUCCESS: string;
        };
    };
    TUITranslatePlugin: {
        SERVICE: {
            NAME: string;
        };
    };
    TUIVoiceToTextPlugin: {
        SERVICE: {
            NAME: string;
        };
    };
    TUICustomerServicePlugin: {
        SERVICE: {
            NAME: string;
            METHOD: {
                ACTIVE_CONVERSATION: string;
                FILTER_MESSAGE: string;
            };
        };
        EXTENSION: {};
    };
    TUIPushPlugin: {
        SERVICE: {
            NAME: string;
        };
    };
    TUIChatbotPlugin: {
        SERVICE: {
            NAME: string;
        };
    };
};

declare const tuiCore: ITUICore;
declare const tuiLogin: ITUILogin;

export { CallServiceParams, ExtensionInfo, LoginParams, TUIConstants, tuiCore as TUICore, tuiLogin as TUILogin, tuiCore as default, func };
